import { Component, OnInit, NgModule, Inject, Input } from '@angular/core';
import { MatDialog, MatDialogRef, MAT_DIALOG_DATA, MatDialogModule, MatDialogConfig } from '@angular/material';
import { Location } from '@angular/common';
// import { HttpClientModule, HttpClient, HttpHeaders, HttpErrorResponse } from '@angular/common/http';
import { Observable } from 'rxjs/Observable';
import { Subscription } from 'rxjs';
import { fromEvent } from 'rxjs';
import { timer } from 'rxjs/observable/timer';
import { repeat } from 'rxjs/operators';
import { Router, NavigationStart } from '@angular/router';

import {Strudelapp} from '../strudelapp';
import { StrudelappsService } from '../strudelapps.service';
import { TesService } from '../tes.service';
import {BackendSelectionService } from '../backend-selection.service';
import { AuthorisationService } from '../authorisation.service';
import { Identity } from '../identity';
import { Computesite, Health } from '../computesite';
import { LogoutdialogComponent } from '../logoutdialog/logoutdialog.component';

import { SshAuthzServer } from '../identity';
import { ComputesitesService } from '../computesites.service';
import { BehaviorSubject } from 'rxjs/BehaviorSubject';







@Component({
  selector: 'app-launcher',
  templateUrl: './launcher.component.html',
  styleUrls: ['./launcher.component.css']
})
export class LauncherComponent implements OnInit {
  public strudelapps: Strudelapp[];
  @Input() menuopen: boolean;

  public appSubject: BehaviorSubject<Strudelapp>;
  public authorised: boolean;
  //public identity: Identity;
  public identitySubject: BehaviorSubject<Identity>;

  public identities: Identity[];
  public sshauthzservers: SshAuthzServer[];
  private launchwindow: any;
  private launchwindowWatcher: any;
  private subscriptions: Subscription[];

  constructor( public dialog: MatDialog,
                public tesService: TesService,
                public backendSelectionService: BackendSelectionService,
                public authService: AuthorisationService,
                public computeSitesService: ComputesitesService,
                private router: Router,
                ) {
      this.subscriptions = [];
      this.subscriptions.push(this.authService.sshAuthzServers.subscribe(o => {this.updateSshAuthZServers(o)}));
      this.subscriptions.push(this.computeSitesService.appidentities.subscribe(o => this.navLogin(o)));
      this.subscriptions.push(this.computeSitesService.appidentities.subscribe(o => this.getHealth(o)));
      this.appSubject = new BehaviorSubject<Strudelapp>(null);
      this.identitySubject = new BehaviorSubject<Identity>(null);
  }

  countErrors(a: Health[], b: Health[]) {
    var count: number = 0
    var h: Health;
    for (h of a) {
      if (h.stat == 'error') {
        count++;
      }
    }
    for (h of b) {
      if (h.stat == 'error') {
        count++;
      }
    }
    return count;
  }


  navLogin(o) {
    if (o.length == 0) {
      this.router.navigate(['/login']);
    }
  }

  getHealth(o) {
    for (let id of o) {
      this.tesService.getHealthAlerts(id);
    }
  }

  updateSshAuthZServers(o) {
    this.sshauthzservers = o;
  }

  ngOnInit() {
    this.strudelapps = [];

  }

  ngOnDestroy() {
    for (let s of this.subscriptions) {
      s.unsubscribe();
    }
  }

  selectId(id: Identity) {
    this.identitySubject.next(id);
    this.appSubject.next(null);
  }

  selectApp(app: Strudelapp) {
    this.appSubject.next(app);
  }


}
